@@ -1,14 +1,4 @@
-//! # Lightweight Directory Access Protocol V3 (LDAPv3)
-//! `rasn-ldap` is an implementation of the data types defined in IETF
-//! [RFC 4511] also known LDAPv3. This does not provide
-//! an implementation of a client or server, but provides a shared
-//! implementation to build your own clients and servers.
-//!
-//! [RFC 4511]: https://datatracker.ietf.org/doc/html/rfc4511
-//! [RFC 4513]: https://datatracker.ietf.org/doc/html/rfc4513
-//! [RFC 4517]: https://datatracker.ietf.org/doc/html/rfc4517
-//! [RFC 4512]: https://datatracker.ietf.org/doc/html/rfc4512
-
+#![doc = include_str!("../README.md")]
 #![no_std]
 
 extern crate alloc;
